.. _predicates:

.. module:: sympy.assumptions.predicates

==========
Predicates
==========

Common
======

Tautological
------------

.. autoclass:: sympy.assumptions.predicates.common.IsTruePredicate
   :members:

Commutative
-----------

.. autoclass:: sympy.assumptions.predicates.common.CommutativePredicate
   :members:

Calculus
========

Finite
------

.. autoclass:: sympy.assumptions.predicates.calculus.FinitePredicate
   :members:

Infinite
--------

.. autoclass:: sympy.assumptions.predicates.calculus.InfinitePredicate
   :members:

Matrix
======

Symmetric
---------

.. autoclass:: sympy.assumptions.predicates.matrices.SymmetricPredicate
   :members:

Invertible
----------

.. autoclass:: sympy.assumptions.predicates.matrices.InvertiblePredicate
   :members:

Orthogonal
----------

.. autoclass:: sympy.assumptions.predicates.matrices.OrthogonalPredicate
   :members:

Unitary
-------

.. autoclass:: sympy.assumptions.predicates.matrices.UnitaryPredicate
   :members:

Positive Definite
-----------------

.. autoclass:: sympy.assumptions.predicates.matrices.PositiveDefinitePredicate
   :members:

Upper triangular
----------------

.. autoclass:: sympy.assumptions.predicates.matrices.UpperTriangularPredicate
   :members:

Lower triangular
----------------

.. autoclass:: sympy.assumptions.predicates.matrices.LowerTriangularPredicate
   :members:

Diagonal
--------

.. autoclass:: sympy.assumptions.predicates.matrices.DiagonalPredicate
   :members:

Full rank
---------

.. autoclass:: sympy.assumptions.predicates.matrices.FullRankPredicate
   :members:

Square
------

.. autoclass:: sympy.assumptions.predicates.matrices.SquarePredicate
   :members:

Integer elements
----------------

.. autoclass:: sympy.assumptions.predicates.matrices.IntegerElementsPredicate
   :members:

Real elements
-------------

.. autoclass:: sympy.assumptions.predicates.matrices.RealElementsPredicate
   :members:

Complex elements
----------------

.. autoclass:: sympy.assumptions.predicates.matrices.ComplexElementsPredicate
   :members:

Singular
--------

.. autoclass:: sympy.assumptions.predicates.matrices.SingularPredicate
   :members:

Normal
------

.. autoclass:: sympy.assumptions.predicates.matrices.NormalPredicate
   :members:

Triangular
----------

.. autoclass:: sympy.assumptions.predicates.matrices.TriangularPredicate
   :members:

Unit triangular
---------------

.. autoclass:: sympy.assumptions.predicates.matrices.UnitTriangularPredicate
   :members:

Number Theory
=============

Even
----

.. autoclass:: sympy.assumptions.predicates.ntheory.EvenPredicate
   :members:

Odd
---

.. autoclass:: sympy.assumptions.predicates.ntheory.OddPredicate
   :members:

Prime
-----

.. autoclass:: sympy.assumptions.predicates.ntheory.PrimePredicate
   :members:

Composite
---------

.. autoclass:: sympy.assumptions.predicates.ntheory.CompositePredicate
   :members:

Order
=====

Positive
--------

.. autoclass:: sympy.assumptions.predicates.order.PositivePredicate
   :members:

Negative
--------

.. autoclass:: sympy.assumptions.predicates.order.NegativePredicate
   :members:

Zero
----

.. autoclass:: sympy.assumptions.predicates.order.ZeroPredicate
   :members:

Nonzero
-------

.. autoclass:: sympy.assumptions.predicates.order.NonZeroPredicate
   :members:

Nonpositive
-----------

.. autoclass:: sympy.assumptions.predicates.order.NonPositivePredicate
   :members:

Nonnegative
-----------

.. autoclass:: sympy.assumptions.predicates.order.NonNegativePredicate
   :members:

Sets
====

Integer
-------

.. autoclass:: sympy.assumptions.predicates.sets.IntegerPredicate
   :members:

Rational
--------

.. autoclass:: sympy.assumptions.predicates.sets.RationalPredicate
   :members:

Irrational
----------

.. autoclass:: sympy.assumptions.predicates.sets.IrrationalPredicate
   :members:

Real
----

.. autoclass:: sympy.assumptions.predicates.sets.RealPredicate
   :members:

Extended real
-------------

.. autoclass:: sympy.assumptions.predicates.sets.ExtendedRealPredicate
   :members:

Hermitian
---------

.. autoclass:: sympy.assumptions.predicates.sets.HermitianPredicate
   :members:

Complex
-------

.. autoclass:: sympy.assumptions.predicates.sets.ComplexPredicate
   :members:

Imaginary
---------

.. autoclass:: sympy.assumptions.predicates.sets.ImaginaryPredicate
   :members:

Antihermitian
-------------

.. autoclass:: sympy.assumptions.predicates.sets.AntihermitianPredicate
   :members:

Algebraic
---------

.. autoclass:: sympy.assumptions.predicates.sets.AlgebraicPredicate
   :members:

Transcendental
--------------

.. autoclass:: sympy.assumptions.predicates.sets.TranscendentalPredicate
   :members:
